You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@struts.apache.org by he...@apache.org on 2006/04/12 19:56:50 UTC

svn commit: r393547 - /incubator/webwork2/action/src/main/java/org/apache/struts/action2/views/velocity/VelocityManager.java

Author: hermanns
Date: Wed Apr 12 10:56:49 2006
New Revision: 393547

URL: http://svn.apache.org/viewcvs?rev=393547&view=rev
Log:
replacing all occurances of wwfile --> saffile and wwclass --> safclass for Velocity integration

Modified:
    incubator/webwork2/action/src/main/java/org/apache/struts/action2/views/velocity/VelocityManager.java

Modified: incubator/webwork2/action/src/main/java/org/apache/struts/action2/views/velocity/VelocityManager.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/action/src/main/java/org/apache/struts/action2/views/velocity/VelocityManager.java?rev=393547&r1=393546&r2=393547&view=diff
==============================================================================
--- incubator/webwork2/action/src/main/java/org/apache/struts/action2/views/velocity/VelocityManager.java (original)
+++ incubator/webwork2/action/src/main/java/org/apache/struts/action2/views/velocity/VelocityManager.java Wed Apr 12 10:56:49 2006
@@ -477,30 +477,30 @@
          * Ben Hall (22/08/2003)
          */
         if (p.getProperty(Velocity.RESOURCE_LOADER) == null) {
-            p.setProperty(Velocity.RESOURCE_LOADER, "wwfile, wwclass");
+            p.setProperty(Velocity.RESOURCE_LOADER, "saffile, safclass");
         }
 
         /**
          * If there's a "real" path add it for the wwfile resource loader.
          * If there's no real path and they haven't configured a loader then we change
          * resource loader property to just use the wwclass loader
          * Ben Hall (22/08/2003)
          */
         if (context.getRealPath("") != null) {
-            p.setProperty("wwfile.resource.loader.description", "Velocity File Resource Loader");
-            p.setProperty("wwfile.resource.loader.class", "org.apache.velocity.runtime.resource.loader.FileResourceLoader");
-            p.setProperty("wwfile.resource.loader.path", context.getRealPath(""));
-            p.setProperty("wwfile.resource.loader.modificationCheckInterval", "2");
-            p.setProperty("wwfile.resource.loader.cache", "true");
+            p.setProperty("saffile.resource.loader.description", "Velocity File Resource Loader");
+            p.setProperty("saffile.resource.loader.class", "org.apache.velocity.runtime.resource.loader.FileResourceLoader");
+            p.setProperty("saffile.resource.loader.path", context.getRealPath(""));
+            p.setProperty("saffile.resource.loader.modificationCheckInterval", "2");
+            p.setProperty("saffile.resource.loader.cache", "true");
         } else {
             // remove wwfile from resource loader property
             String prop = p.getProperty(Velocity.RESOURCE_LOADER);
-            if (prop.indexOf("wwfile,") != -1) {
-                prop = replace(prop, "wwfile,", "");
-            } else if (prop.indexOf(", wwfile") != -1) {
-                prop = replace(prop, ", wwfile", "");
-            } else if (prop.indexOf("wwfile") != -1) {
-                prop = replace(prop, "wwfile", "");
+            if (prop.indexOf("saffile,") != -1) {
+                prop = replace(prop, "saffile,", "");
+            } else if (prop.indexOf(", saffile") != -1) {
+                prop = replace(prop, ", saffile", "");
+            } else if (prop.indexOf("saffile") != -1) {
+                prop = replace(prop, "saffile", "");
             }
 
             p.setProperty(Velocity.RESOURCE_LOADER, prop);
@@ -512,10 +512,10 @@
          * Unfortunately, there does not appear to be a macro for the class loader keywords
          * Matt Ho - Mon Mar 17 00:21:46 PST 2003
          */
-        p.setProperty("wwclass.resource.loader.description", "Velocity Classpath Resource Loader");
-        p.setProperty("wwclass.resource.loader.class", "org.apache.struts.action2.views.velocity.StrutsResourceLoader");
-        p.setProperty("wwclass.resource.loader.modificationCheckInterval", "2");
-        p.setProperty("wwclass.resource.loader.cache", "true");
+        p.setProperty("safclass.resource.loader.description", "Velocity Classpath Resource Loader");
+        p.setProperty("safclass.resource.loader.class", "org.apache.struts.action2.views.velocity.StrutsResourceLoader");
+        p.setProperty("safclass.resource.loader.modificationCheckInterval", "2");
+        p.setProperty("safclass.resource.loader.cache", "true");
 
         // components
         StringBuffer sb = new StringBuffer();



---------------------------------------------------------------------
@@ -477,30 +477,30 @@
 
         /**
-         * If there's a "real" path add it for the wwfile resource loader.
+         * If there's a "real" path add it for the saffile resource loader.
          * If there's no real path and they haven't configured a loader then we change
@@ -477,30 +477,30 @@
          * If there's no real path and they haven't configured a loader then we change
-         * resource loader property to just use the wwclass loader
+         * resource loader property to just use the safclass loader
          * Ben Hall (22/08/2003)
          */
@@ -477,30 +477,30 @@
         } else {
-            // remove wwfile from resource loader property
+            // remove saffile from resource loader property
             String prop = p.getProperty(Velocity.RESOURCE_LOADER);
To unsubscribe, e-mail: dev-unsubscribe@struts.apache.org
For additional commands, e-mail: dev-help@struts.apache.org